import { LaunchOptions } from 'puppeteer';

type EngineTypes = "html" | "json" | "xml";
declare enum EngineType {
    Html = "html",
    Json = "json",
    Xml = "xml"
}
type TScrapedData = Record<string, any>;
type TScrapedDataPromise = Promise<TScrapedData>;
interface ISelectorWithAttribute {
    selector: string;
    attribute?: string;
}
type TSelectors = Record<string, ISelectorWithAttribute>;
interface IScrapeDefaultOptions {
    selectors: TSelectors;
}
interface IScrapeHtmlOptions extends IScrapeDefaultOptions {
    spa?: {
        enable: boolean;
        browserConfig: LaunchOptions;
    };
}
interface IScrapeJsonOptions extends IScrapeDefaultOptions {
}
interface IScrapeXmlOptions extends IScrapeDefaultOptions {
}
interface IScrapeOptions {
    url: string;
    engine: EngineType | EngineTypes;
    options: IScrapeHtmlOptions | IScrapeJsonOptions | IScrapeXmlOptions;
}

declare const scrape: ({ url, engine, options, }: IScrapeOptions) => TScrapedDataPromise;

declare const scrapeHtml: (url: string, { selectors, spa }: IScrapeHtmlOptions) => TScrapedDataPromise;

declare const scrapeXml: (url: string, { selectors }: IScrapeXmlOptions) => TScrapedDataPromise;

declare const scrapeJson: (url: string, { selectors }: IScrapeXmlOptions) => TScrapedDataPromise;

export { EngineType, EngineTypes, IScrapeDefaultOptions, IScrapeHtmlOptions, IScrapeJsonOptions, IScrapeOptions, IScrapeXmlOptions, ISelectorWithAttribute, TScrapedData, TScrapedDataPromise, TSelectors, scrape, scrapeHtml, scrapeJson, scrapeXml };
